# mindexer

An experimental tool to recommend indexes for MongoDB

## Description

`mindexer` is a command line tool written in Python to recommend indexes for a MongoDB collection. It uses queries logged to the `system.profile` collection (find out more about [profiling in MongoDB](https://www.mongodb.com/docs/manual/tutorial/manage-the-database-profiler/)) and a small random sample of the original collection to determine the indexes best suited for a workload and dataset.

## Installation

TBD

## Usage

TBD
